@@ -1,3 +1,9 @@
+# Not bash or zsh?
+#[ -n "${BASH_VERSION:-}" ] || return 0
+
+# Not an interactive shell?
+#[[ $- == *i* ]] || return 0
+
 if [[ $DESKTOP_SESSION != 'budgie-desktop' ]]
 then
     return 0
@@ -26,6 +32,8 @@ then
     touch ~/.config/budgie-desktop/keycontrol6
 fi
 
+bash -c 'sleep 5 && /usr/share/budgie-desktop/gdmcheck/gdmcheck.sh' &
+
 if [ -f ~/.config/budgie-desktop/firstrun ]
 then
     return 0
